@@ -43,7 +43,9 @@ __all__ = (
     "ResolverKindType",
     "SchemaStatusType",
     "TypeDefinitionFormatType",
+    "AppSyncServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -99,6 +101,7 @@ SchemaStatusType = Literal[
     "ACTIVE", "DELETING", "FAILED", "NOT_APPLICABLE", "PROCESSING", "SUCCESS"
 ]
 TypeDefinitionFormatType = Literal["JSON", "SDL"]
+AppSyncServiceName = Literal["appsync"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -130,6 +133,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -252,6 +256,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -400,6 +405,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_api_keys",
     "list_data_sources",
